@@ -1,3 +1,5 @@
+from typing import Any
+
 from aiohttp import ClientSession, ClientTimeout
 
 
@@ -9,5 +11,5 @@ class HttpClient:
         }
         self.timeout = ClientTimeout(total=connection_timeout_seconds)
 
-    async def post(self, url: str, data: any, session: ClientSession, **kwargs):
+    async def post(self, url: str, data: Any, session: ClientSession, **kwargs):
         return await session.post(url=url, data=data, headers=self.headers, **kwargs)
